Learn R Programming

marl (version 1.0)

negbin.rel.clust: Relative Likelihood based clustering assuming Negative Binomial distribution.

Description

The function provides weighted relative likelihood function matrix, cluster assigment based on k means clustering, and plot of weighted relative likelihood functions with colors representing cluster assignment. Each observation in the dataset is assumed to follow negative binomial distribution.

Usage

negbin.rel.clust(x, mu.min, mu.max, nclust = 2, len = 200, plot = TRUE, seed = 132)

Arguments

x
Observations of length greater than 1. Data can be entered as matrix or list.
mu.min
Minimum value of mu for the relative likelihood function.
mu.max
Maximum value of mu for the relative likelihood function.
nclust
Number of Clusters.
len
Length of values to be evaluated at in between mu.min and mu.max.
plot
If set TRUE, provides plot of weighted relative likelihood functions colored by their cluster assignment.
seed
Seed to be set for reproducibile results.

Value

Wt.Rel.Likld
A matrix of weighted relative likelihood functions with rows indicating observations. The column names are the values at which the weighted relative likelihood functions are evaluated.
Cluster.Assignment
Cluster assignment for each observation.
table
Table summarizing size of clusters.

Details

For mathematical details, please contact the authors.

References

None.

Examples

Run this code
x <- sim.negbin(c(4,5,10),3,10,12)
negbin.rel.clust(x,1,20,nclust = 3,len=200,plot=TRUE,seed=132)

Run the code above in your browser using DataLab