Learn R Programming

marl (version 1.0)

pois.rel.clust: Relative Likelihood based clustering assuming Poisson distribution.

Description

The function provides weighted relative likelihood function matrix, cluster assigment based on k means clustering, and plot of weighted relative likelihood functions with colors representing cluster assignment. Each observation in the dataset is assumed to follow Poisson distribution.

Usage

pois.rel.clust(x, lambda.min, lambda.max, nclust = 3, len = 200, plot = TRUE, seed = 132)

Arguments

x
Data can be entered as matrix or list.
lambda.min
Minimum value of lambda.
lambda.max
Maximum value of lambda.
nclust
Number of Clusters.
len
Length of values to be evaluated at in between lambda.min and lambda.max.
plot
If set TRUE, provides plot of weighted relative likelihood functions colored by their cluster assignment.
seed
Seed to be set for reproducibility

Value

Wt.Rel.Likld
A matrix of weighted relative likelihood functions with rows indicating observations. The column names are the values at which the weighted relative likelihood functions are evaluated.
Cluster.Assignment
Cluster assignment of each observation.
table
Table summarizing size of clusters.

Details

For mathematical details, please contact the authors.

References

None.

Examples

Run this code
x <- sim.pois(c(4,10),5,4)
pois.rel.clust(x,1,20,nclust = 2,len=200,plot=TRUE,seed=132)

Run the code above in your browser using DataLab