Learn R Programming

marl (version 1.0)

pois.rel.pca: Relative Likelihood based clustering assuming Poisson distribution.

Description

The function performs PCA on matrix based on weighted relative likelihood function and provides a plot of first two PCs as well as summary of PCA.

Usage

pois.rel.pca(x, lambda.min, lambda.max, len = 10, plot = TRUE, seed = 132)

Arguments

x
Data can be entered as matrix or list.
lambda.min
Minimum value of lambda.
lambda.max
Maximum value of lambda.
len
Length of values to be evaluated at in between mu.min and mu.max.
plot
If set TRUE, provides plot of weighted relative likelihood functions colored by their cluster assignment.
seed
Seed to be set for reproducibility

Value

PCA.output
Summary of Principal Component Analysis

Details

For mathematical details, please contact the authors.

References

None.

Examples

Run this code
x <- sim.pois(c(4,10),15,10)
pois.rel.pca(x,1,20,len=20,plot=TRUE,seed=132)

Run the code above in your browser using DataLab