pois.rel.clust: Relative Likelihood based clustering assuming Poisson distribution.
Description
The function provides weighted relative likelihood function matrix, cluster assigment based on k means clustering, and plot of weighted relative likelihood functions with colors representing cluster assignment. Each observation in the dataset is assumed to follow Poisson distribution.
Length of values to be evaluated at in between lambda.min and lambda.max.
plot
If set TRUE, provides plot of weighted relative likelihood functions colored by their cluster assignment.
seed
Seed to be set for reproducibility
Value
Wt.Rel.Likld
A matrix of weighted relative likelihood functions with rows indicating observations. The column names are the values at which the weighted relative likelihood functions are evaluated.
Cluster.Assignment
Cluster assignment of each observation.
table
Table summarizing size of clusters.
Details
For mathematical details, please contact the authors.