wt.rel.pois: Weighted relative likelihood function based on Poisson distribution.
Description
This function constructs wt. rel. likld.function based on Poisson distribution. It provides plot, area under curve, mle, and values of wt. rel. function
Usage
wt.rel.pois(x, lambda.min, lambda.max, plot = TRUE, len = 100)
Arguments
x
vector or list of observations
lambda.min
Minimum value of lambda.
lambda.max
Maximum value of lambda.
plot
If TRUE provides a plot of weighted relative likelihood functions.
len
Length of values to be evaluated at in between lambda.min and lambda.max
Value
mle
Mode of the likelihood function.
AUC
Area under curve of the wt. rel. likld function. Estimated numerically using optimize function.
Lambda
Values of lambda between lambda.min and lambda.max
Val
Values of wt. rel. likld. function evaluated at mu.
Details
For mathematical details, please contact the authors.